==> v3.3.10.tar.gz: cost-benefit-projection/README.md <==
# Cost Benefit Projection (3.3.10)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Cost Benefit Projection image] (https://raw.githubusercontent.com/namibia/CBP-Joomla-3-Component/master/admin/assets/images/component-300.png "The Cost Benefit Projection")

[Create Epidemiological Profiles] (https://www.staffhealthcbp.com/) for diseases and risks affecting your company. Detailed information on projected work days lost and costs. Create and edit activities and wellness responses for your workplace. Access to Small Business Modelling. Results displayed by gender. Network with other companies and wellness professionals.

Having seen the health priorities for your workforce, the tool outputs projections for how the interventions – which you have designed - are expected to benefit the company financially.

Benefits are calculated based on the model projecting reductions in workdays lost due to sickness, presenteeism and death.

# Requirements

Due to the size of the permissional structure, you will need to increase max_input_vars until the permissions are able to save.
```
max_input_vars = 5000
```
# Build Details

+ *Company*: [Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb] (https://www.staffhealthcbp.com/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Cost Benefit Projection] (https://www.staffhealthcbp.com/)
+ *First Build*: 15th June, 2012
+ *Last Build*: 22nd March, 2016
+ *Version*: 3.3.10
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **83985**
+ *File count*: **558**
+ *Folder count*: **101**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)

==> v3.4.1.tar.gz: cost-benefit-projection/README.md <==
# Cost Benefit Projection (3.4.1)

This is a [Joomla 3.x] (http://www.joomla.org/) component.

 ![Cost Benefit Projection image] (https://raw.githubusercontent.com/namibia/CBP-Joomla-3-Component/master/admin/assets/images/component-300.png "The Cost Benefit Projection")

[Create Epidemiological Profiles] (https://www.staffhealthcbp.com/) for diseases and risks affecting your company. Detailed information on projected work days lost and costs. Create and edit activities and wellness responses for your workplace. Access to Small Business Modelling. Results displayed by gender. Network with other companies and wellness professionals.

Having seen the health priorities for your workforce, the tool outputs projections for how the interventions – which you have designed - are expected to benefit the company financially.

Benefits are calculated based on the model projecting reductions in workdays lost due to sickness, presenteeism and death.

# Requirements

Due to the size of the permissional structure, you will need to increase max_input_vars until the permissions are able to save.
```
max_input_vars = 5000
```
# Build Details

+ *Company*: [Deutsche Gesellschaft für International Zusammenarbeit (GIZ) Gmb] (https://www.staffhealthcbp.com/)
+ *Author*: [Llewellyn van der Merwe] (mailto:llewellyn@vdm.io)
+ *Name*: [Cost Benefit Projection] (https://www.staffhealthcbp.com/)
+ *First Build*: 15th June, 2012
+ *Last Build*: 14th May, 2016
+ *Version*: 3.4.1
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html
+ *Line count*: **86020**
+ *File count*: **570**
+ *Folder count*: **103**

> This **component** was build with a Joomla [Automated Component Builder] (https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe] (mailto:joomla@vdm.io)
